# crashplan

#### Table of Contents

1. [Description](#description)
1. [Setup - The basics of getting started with crashplan](#setup)
    * [Beginning with crashplan](#beginning-with-crashplan)
1. [Usage - Configuration options and additional functionality](#usage)
1. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
1. [Limitations - OS compatibility, etc.](#limitations)

## Description

This module installs and configures the CrashPlan backup service. Currently works
on Linux (tested on CentOS 7.3 with Puppet 4.9, should work for older versions and other distros)

## Setup

No special setup should be required.

### Beginning with crashplan

```
include crashplan
```

## Usage

You can specify the URL that the module downloads CrashPlan from by passing the crashplan_source
parameter, like so:

```
class {crashplan:
  crashplan_source => 'http://some_url',
}
```

You can also specify the port that the CrashPlan service will listen to, as well as the GUID
that desktop clients must use to connect (for headless installs):

```
class {crashplan:
  server_port => '4300',
  auth_guid => '6690f1b9-e3b7-444e-bfd1-9afd06bd896c',
}
```

See https://support.code42.com/CrashPlan/4/Configuring/Using_CrashPlan_On_A_Headless_Computer
for more information on how to configure your desktop client to connect to a headless install.

## Reference

### crashplan

The main class, and the only one you should need to use. Calls the other classes in order
to install and configure the software.

#### Parameters

**crashplan_source**: String, specifies the URL to download CrashPlan from.
**server_port**: String, specifies the port to listen on.
**auth_guid**: String, specifies the GUID used to connect the desktop client to the service.

### crashplan::install

Downloads, extracts, and installs the CrashPlan software.

### crashplan::configure

Configures settings used by CrashPlan.

### crashplan::service

Manages the CrashPlan service.

## Limitations

Should be compatible with any Linux distribution CrashPlan supports. Tested on CentOS 7.3
with Puppet 4.9, but should be compatible with older Puppet versions as well.
