# Class: crashplan
# ===========================
#
# This class installs and configures CrashPlan 4.8.2 for Linux.
#
# Parameters
# ----------
#
# Document parameters here.
#
# * `crashplan_source`
# Specify the archive to download for CrashPlan as a string. Defaults to the
# latest archive at the time the module is published.
#
# * `server_port`
# Specify what port the CrashPlan service should listen on as a string.
# Default is 4243.
#
# * `auth_guid`
# Specify the GUID that will be stored in /var/lib/crashplan/.ui_info as a string.
# Used to connect the desktop client to a headless install.
# See https://support.code42.com/CrashPlan/4/Configuring/Using_CrashPlan_On_A_Headless_Computer for more info.
#
# Examples
# --------
#
# @example
#    class { 'crashplan':
#      server_port => '4582',
#    }
#
# Authors
# -------
#
# Chris Drzewiecki <chris@fdisk.io>
#
# Copyright
# ---------
#
# Copyright 2017 Chris Drzewiecki, unless otherwise noted.
#
class crashplan (
  String $crashplan_source = $crashplan::params::crashplan_source,
  String $server_port = $crashplan::params::server_port,
  String $auth_guid = $crashplan::params::auth_guid,
) inherits crashplan::params {
  class {crashplan::install:
    crashplan_source => $crashplan_source,
  }
  include crashplan::configure
  include crashplan::service

  Class['crashplan::install'] -> Class['crashplan::configure'] ~> Class['crashplan::service']
}
